@@ -32,7 +32,7 @@ from argo_workflow_tools.models.io.argoproj.workflow import v1alpha1 as argo
 
 
 def _create_task_script(
-    func_obj: TaskReference, parameters: Dict[str, argo.Parameter]
+        func_obj: TaskReference, parameters: Dict[str, argo.Parameter]
 ) -> str:
     """
     generates a runnable script out of a task function, adding input and output boilerplate
@@ -48,7 +48,7 @@ def _create_task_script(
         return None
     code = inspect.getsource(func_obj.func)
     function_signature = inspect.signature(func_obj.func)
-    code = code[code.find("def ") :]
+    code = code[code.find("def "):]
     builder_imports = set()
     inputs = ""
     outputs = ""
@@ -59,17 +59,17 @@ def _create_task_script(
         )
         builder_imports = builder_imports.union(json_parameter.imports())
         inputs += (
-            json_parameter.variable_from_input(parameters[name].name, name, func_obj)
-            + os.linesep
+                json_parameter.variable_from_input(parameters[name].name, name, func_obj)
+                + os.linesep
         )
 
     for name, argument in func_obj.outputs.items():
         builder_imports = builder_imports.union(argument.parameter_builder.imports())
         outputs += (
-            argument.parameter_builder.variable_to_output(
-                argument.name, name, func_obj.func
-            )
-            + os.linesep
+                argument.parameter_builder.variable_to_output(
+                    argument.name, name, func_obj.func
+                )
+                + os.linesep
         )
     if outputs == "":
         output_builder = func_obj.properties.outputs.get(
@@ -79,11 +79,11 @@ def _create_task_script(
     call = f"result={func_obj.func.__name__}({str.join(',', inspect.signature(func_obj.func).parameters.keys())})"
     builder_imports = str.join(os.linesep, list(builder_imports))
     script = (
-        f"{builder_imports}\n"
-        + f"{code}\n"
-        + f"{inputs}\n"
-        + f"{call}\n"
-        + f"{outputs}"
+            f"{builder_imports}\n"
+            + f"{code}\n"
+            + f"{inputs}\n"
+            + f"{call}\n"
+            + f"{outputs}"
     )
     return script
 
@@ -137,7 +137,7 @@ def _generate_task_name_from_node_uid(nodes: List[NodeReference]) -> Dict[str, s
     # first
     sorted_nodes = sorted(nodes, key=lambda node_reference: node_reference.name)
     for name, group in groupby(
-        sorted_nodes, key=lambda node_reference: node_reference.name
+            sorted_nodes, key=lambda node_reference: node_reference.name
     ):
         duplicate_nodes = list(group)
 
@@ -150,7 +150,7 @@ def _generate_task_name_from_node_uid(nodes: List[NodeReference]) -> Dict[str, s
 
 
 def _build_with(
-    params: List[InputDefinition], unique_node_names_map: Dict[str, str]
+        params: List[InputDefinition], unique_node_names_map: Dict[str, str]
 ) -> Optional[str]:
     """
     builds "with" param for loop DAGs by analyzing the inputs and looking iterable inputs.
@@ -173,31 +173,28 @@ def build_condition(conditions: List[Union[BinaryOp, UnaryOp]]):
     if not conditions or len(conditions) == 0:
         return None
 
-    condition_expr = [condition for condition in conditions]
+    condition_expr = [condition.condition_string() for condition in conditions]
 
     return "&&".join(condition_expr)
 
 
 def _build_dag_task(
-    dag_task: NodeReference, unique_node_names_map: Dict[str, str]
+        dag_task: NodeReference, unique_node_names_map: Dict[str, str]
 ) -> argo.DagTask:
     potential_deps = list(dag_task.arguments.values())
-    potential_deps.append(list()
-                    if dag_task.wait_for is None
-                    else dag_task.wait_for)
+    potential_deps.extend(list()
+                          if dag_task.wait_for is None
+                          else dag_task.wait_for)
     dependencies = set(
-        filter(
-            lambda dependency: dependency,
-            [
-                input_dep.source_node_id
-                for input_dep in filter(
-                    lambda x: isinstance(x, InputDefinition)
-                    and not x.source_type == SourceType.PARAMETER,
-                    potential_deps
-                )
-            ],
-        )
+
+        [input_dep.source_node_id
+         for input_dep in filter(
+            lambda x: isinstance(x, InputDefinition)
+                      and x.is_node_output,
+            potential_deps
+        )]
     )
+
     with_param = _build_with(dag_task.arguments.values(), unique_node_names_map)
     arguments = [
         _build_node_input(input_name, input_type)
@@ -244,7 +241,7 @@ def _build_dag_task(
 
 
 def _build_node_input(input_name: str, input_def: InputDefinition) -> argo.Parameter:
-    return argo.Parameter(name=sanitize_name(input_name,snake_case=True), value=input_def.path())
+    return argo.Parameter(name=sanitize_name(input_name, snake_case=True), value=input_def.path())
 
 
 def _build_input_parameter(parameter: InputDefinition) -> argo.Parameter:
@@ -253,7 +250,7 @@ def _build_input_parameter(parameter: InputDefinition) -> argo.Parameter:
     """
     if parameter.source_type == SourceType.PARAMETER:
         argo_parameter = argo.Parameter(
-            name=sanitize_name(parameter.name,snake_case=True), default=parameter.default
+            name=sanitize_name(parameter.name, snake_case=True), default=parameter.default
         )
         return argo_parameter
     else:
@@ -264,11 +261,11 @@ def _build_input_parameter(parameter: InputDefinition) -> argo.Parameter:
 
 
 def _build_dag_outputs(
-    dag_output: Union[
-        None,
-        InputDefinition,
-        Mapping[str, InputDefinition],
-    ]
+        dag_output: Union[
+            None,
+            InputDefinition,
+            Mapping[str, InputDefinition],
+        ]
 ) -> List[Union[argo.Parameter, argo.Artifact]]:
     """
     Builds DAG output parameter out of DAG definition
@@ -276,8 +273,8 @@ def _build_dag_outputs(
     outputs: Mapping[str, InputDefinition] = {}
 
     if (
-        isinstance(dag_output, InputDefinition)
-        and dag_output.source_type == SourceType.NODE_OUTPUT
+            isinstance(dag_output, InputDefinition)
+            and dag_output.source_type == SourceType.NODE_OUTPUT
     ):
         outputs = {"result": dag_output}
     elif isinstance(dag_output, Mapping):
@@ -312,10 +309,10 @@ def _build_task_template(task_node: TaskReference) -> argo.Template:
     parameters = {
         param_name: InputDefinition(
             source_type=SourceType.PARAMETER,
-            name=sanitize_name(param_name,snake_case=True),
+            name=sanitize_name(param_name, snake_case=True),
             default=None
             if isinstance(param_definition.default, type)
-            and param_definition.default.__name__ == "_empty"
+               and param_definition.default.__name__ == "_empty"
             else param_definition.default,
         )
         for param_name, param_definition in inspect.signature(
@@ -373,10 +370,10 @@ def _build_dag_template(node: DAGNode) -> argo.Template:
     parameters = {
         param_name: InputDefinition(
             source_type=SourceType.PARAMETER,
-            name=sanitize_name(param_name,snake_case=True),
+            name=sanitize_name(param_name, snake_case=True),
             default=None
             if isinstance(param_definition.default, type)
-            and param_definition.default.__name__ == "_empty"
+               and param_definition.default.__name__ == "_empty"
             else param_definition.default,
         )
         for param_name, param_definition in inspect.signature(
